@@ -27,6 +27,8 @@ union KC_YYSTYPE {
     kc::tRepeatEvery yt_tRepeatEvery;
     kc::tVariable_list yt_tVariable_list;
     kc::tVariable yt_tVariable;
+    kc::tMessageExchange_list yt_tMessageExchange_list;
+    kc::tMessageExchange yt_tMessageExchange;
     kc::tCorrelationSet_list yt_tCorrelationSet_list;
     kc::tCorrelationSet yt_tCorrelationSet;
     kc::tCorrelation_list yt_tCorrelation_list;
