@@ -1,23 +1,29 @@
 /*****************************************************************************\
- * Copyright 2005, 2006, 2007 Niels Lohmann, Christian Gierds                *
- *                                                                           *
- * This file is part of GNU BPEL2oWFN.                                       *
- *                                                                           *
- * GNU BPEL2oWFN is free software; you can redistribute it and/or modify it  *
- * under the terms of the GNU General Public License as published by the     *
- * Free Software Foundation; either version 2 of the License, or (at your    *
- * option) any later version.                                                *
- *                                                                           *
- * GNU BPEL2oWFN is distributed in the hope that it will be useful, but      *
- * WITHOUT ANY WARRANTY; without even the implied warranty of                *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General  *
- * Public License for more details.                                          *
- *                                                                           *
- * You should have received a copy of the GNU General Public License along   *
- * with GNU BPEL2oWFN; see file COPYING. if not, write to the Free Software  *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA. *
+  GNU BPEL2oWFN -- Translating BPEL Processes into Petri Net Models
+
+  Copyright (C) 2006, 2007  Niels Lohmann,
+                            Christian Gierds, and
+                            Martin Znamirowski
+  Copyright (C) 2005        Niels Lohmann and
+			    Christian Gierds
+
+  GNU BPEL2oWFN is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by the Free
+  Software Foundation; either version 3 of the License, or (at your option) any
+  later version.
+
+  GNU BPEL2oWFN is distributed in the hope that it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+  details.
+
+  You should have received a copy of the GNU General Public License along with
+  GNU BPEL2oWFN (see file COPYING); if not, see http://www.gnu.org/licenses
+  or write to the Free Software Foundation,Inc., 51 Franklin Street, Fifth
+  Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
+
 /*!
  * \file    options.cc
  *
@@ -29,13 +35,13 @@
  *
  * \since   2005/10/18
  *
- * \date    \$Date: 2007/06/13 20:01:04 $
+ * \date    \$Date: 2007/06/28 07:38:16 $
  *
  * \note    This file is part of the tool BPEL2oWFN and was created during the
  *          project "Tools4BPEL" at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.88 $
+ * \version \$Revision: 1.89 $
  */
 
 
@@ -141,7 +147,7 @@ void print_help()
 {
   // 80 chars
   //    "12345678901234567890123456789012345678901234567890123456789012345678901234567890"
-  trace(string(PACKAGE_NAME) + " - translates a BPEL process to an open workflow net\n");
+  trace(string(PACKAGE_NAME) + " -- Translating BPEL Processes into Petri Net Models\n");
   trace("\n");
   trace("Usage: " + globals::program_name + " [OPTION]\n");
   trace("\n");
@@ -199,9 +205,9 @@ void print_version()
   trace(string(PACKAGE_STRING) + " (compiled " + string(__DATE__) + ")\n\n");
   trace("Copyright (C) 2006, 2007 Niels Lohmann, Christian Gierds and Martin Znamirowski\n");
   trace("Copyright (C) 2005 Niels Lohmann and Christian Gierds\n\n");
-  trace("There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR\n");
-  trace("PURPOSE. You may redistribute copies of " + string(PACKAGE_NAME) + " under the terms of the\n");
-  trace("GNU General Public License. See file COPYING for information.\n\n");
+  trace("License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n");
+  trace(string(PACKAGE_NAME) + " is free software: you are free to change and redistribute it.\n");
+  trace("There is NO WARRANTY, to the extent permitted by law.\n\n");  
   trace("See http://www.gnu.org/software/bpel2owfn for more information\n");
 }
 
