@@ -1,22 +1,26 @@
 /*****************************************************************************\
- * Copyright 2007        Niels Lohmann, Christian Gierds, Martin Znamirowski *
- * Copyright 2005, 2006  Niels Lohmann, Christian Gierds                     *
- *                                                                           *
- * This file is part of GNU BPEL2oWFN.                                       *
- *                                                                           *
- * GNU BPEL2oWFN is free software; you can redistribute it and/or modify it  *
- * under the terms of the GNU General Public License as published by the     *
- * Free Software Foundation; either version 2 of the License, or (at your    *
- * option) any later version.                                                *
- *                                                                           *
- * GNU BPEL2oWFN is distributed in the hope that it will be useful, but      *
- * WITHOUT ANY WARRANTY; without even the implied warranty of                *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General  *
- * Public License for more details.                                          *
- *                                                                           *
- * You should have received a copy of the GNU General Public License along   *
- * with GNU BPEL2oWFN; see file COPYING. if not, write to the Free Software  *
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA. *
+  GNU BPEL2oWFN -- Translating BPEL Processes into Petri Net Models
+
+  Copyright (C) 2006, 2007  Niels Lohmann,
+                            Christian Gierds, and
+                            Martin Znamirowski
+  Copyright (C) 2005        Niels Lohmann and
+			    Christian Gierds
+
+  GNU BPEL2oWFN is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by the Free
+  Software Foundation; either version 3 of the License, or (at your option) any
+  later version.
+
+  GNU BPEL2oWFN is distributed in the hope that it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+  details.
+
+  You should have received a copy of the GNU General Public License along with
+  GNU BPEL2oWFN (see file COPYING); if not, see http://www.gnu.org/licenses
+  or write to the Free Software Foundation,Inc., 51 Franklin Street, Fifth
+  Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
 /*!
@@ -31,13 +35,13 @@
  *
  * \since   2005-10-18
  *
- * \date    \$Date: 2007/06/05 15:04:00 $
+ * \date    \$Date: 2007/06/28 07:38:17 $
  *
  * \note    This file is part of the tool GNU BPEL2oWFN and was created during
  *          the project Tools4BPEL at the Humboldt-Universitt zu Berlin. See
  *          http://www.informatik.hu-berlin.de/top/tools4bpel for details.
  *
- * \version \$Revision: 1.218 $
+ * \version \$Revision: 1.222 $
  *
  * \ingroup petrinet
  */
@@ -356,14 +360,16 @@ PetriNet::PetriNet(const PetriNet & net)
   roleMap.clear();
 
 
-  nextId = 1;
+  nextId = net.nextId;
   format = FORMAT_OWFN;
 
   // add all internal places
   for (set< Place * >::iterator place = net.P.begin(); place != net.P.end(); place ++)
   {
     Place * newPlace = new Place( **place );
-    newPlace->id = getId();
+    newPlace->id = (*place)->id;
+    newPlace->preset.clear();
+    newPlace->postset.clear();
     P.insert( newPlace );
 
     roleMap[ newPlace->nodeFullName() ] = newPlace;
@@ -375,7 +381,9 @@ PetriNet::PetriNet(const PetriNet & net)
   for (set< Place * >::iterator place = net.P_in.begin(); place != net.P_in.end(); place ++)
   {
     Place * newPlace = new Place( **place );
-    newPlace->id = getId();
+    newPlace->id = (*place)->id;
+    newPlace->preset.clear();
+    newPlace->postset.clear();
     P_in.insert( newPlace );
 
     roleMap[ newPlace->nodeFullName() ] = newPlace;
@@ -387,7 +395,9 @@ PetriNet::PetriNet(const PetriNet & net)
   for (set< Place * >::iterator place = net.P_out.begin(); place != net.P_out.end(); place ++)
   {
     Place * newPlace = new Place( **place );
-    newPlace->id = getId();
+    newPlace->id = (*place)->id;
+    newPlace->preset.clear();
+    newPlace->postset.clear();
     P_out.insert( newPlace );
 
     roleMap[ newPlace->nodeFullName() ] = newPlace;
@@ -399,7 +409,9 @@ PetriNet::PetriNet(const PetriNet & net)
   for (set< Transition * >::iterator transition = net.T.begin(); transition != net.T.end(); transition ++)
   {
     Transition * newTransition = new Transition( **transition );
-    newTransition->id = getId();
+    newTransition->id = (*transition)->id;
+    newTransition->preset.clear();
+    newTransition->postset.clear();
     T.insert( newTransition );
 
     roleMap[ newTransition->nodeFullName() ] = newTransition;
@@ -456,14 +468,14 @@ PetriNet & PetriNet::operator=(const PetriNet & net)
   roleMap.clear();
 
 
-  nextId = 1;
+  nextId = net.nextId;
   format = FORMAT_OWFN;
 
   // add all internal places
   for (set< Place * >::iterator place = net.P.begin(); place != net.P.end(); place ++)
   {
     Place * newPlace = new Place( **place );
-    newPlace->id = getId();
+    newPlace->id = (*place)->id;
     newPlace->preset.clear();
     newPlace->postset.clear();
     P.insert( newPlace );
@@ -477,7 +489,7 @@ PetriNet & PetriNet::operator=(const PetriNet & net)
   for (set< Place * >::iterator place = net.P_in.begin(); place != net.P_in.end(); place ++)
   {
     Place * newPlace = new Place( **place );
-    newPlace->id = getId();
+    newPlace->id = (*place)->id;
     newPlace->preset.clear();
     newPlace->postset.clear();
     P_in.insert( newPlace );
@@ -491,7 +503,7 @@ PetriNet & PetriNet::operator=(const PetriNet & net)
   for (set< Place * >::iterator place = net.P_out.begin(); place != net.P_out.end(); place ++)
   {
     Place * newPlace = new Place( **place );
-    newPlace->id = getId();
+    newPlace->id = (*place)->id;
     newPlace->preset.clear();
     newPlace->postset.clear();
     P_out.insert( newPlace );
@@ -505,7 +517,7 @@ PetriNet & PetriNet::operator=(const PetriNet & net)
   for (set< Transition * >::iterator transition = net.T.begin(); transition != net.T.end(); transition ++)
   {
     Transition * newTransition = new Transition( **transition );
-    newTransition->id = getId();
+    newTransition->id = (*transition)->id;
     newTransition->preset.clear();
     newTransition->postset.clear();
     T.insert( newTransition );
